var group__real_s_ycomputational =
[
    [ "sla_syamv", "d0/d14/group__real_s_ycomputational_ga1eb39049af684991f53c9be704fbc56d.html#ga1eb39049af684991f53c9be704fbc56d", null ],
    [ "sla_syrcond", "d0/d14/group__real_s_ycomputational_ga2d103aec11d1fe30e887c40f6173da32.html#ga2d103aec11d1fe30e887c40f6173da32", null ],
    [ "sla_syrfsx_extended", "d0/d14/group__real_s_ycomputational_ga99d1d125b5f45e1007185a8addf408ab.html#ga99d1d125b5f45e1007185a8addf408ab", null ],
    [ "sla_syrpvgrw", "d0/d14/group__real_s_ycomputational_ga0710d9e3e5ee6bcf61e9edebc7d3cf4f.html#ga0710d9e3e5ee6bcf61e9edebc7d3cf4f", null ],
    [ "slasyf", "d0/d14/group__real_s_ycomputational_ga409610d6bc329d424d5a8a1d2640c445.html#ga409610d6bc329d424d5a8a1d2640c445", null ],
    [ "slasyf_aa", "d0/d14/group__real_s_ycomputational_gade2284d3213798f5ab22eeaa6b9b9b03.html#gade2284d3213798f5ab22eeaa6b9b9b03", null ],
    [ "slasyf_rook", "d0/d14/group__real_s_ycomputational_gab56807ae53bfd2750b0a03d5cdc738a2.html#gab56807ae53bfd2750b0a03d5cdc738a2", null ],
    [ "ssycon", "d0/d14/group__real_s_ycomputational_gab3e2f689a6ee4b436702ace446df4781.html#gab3e2f689a6ee4b436702ace446df4781", null ],
    [ "ssycon_rook", "d0/d14/group__real_s_ycomputational_ga7fcaab2596faf934aacea4f34f8dd857.html#ga7fcaab2596faf934aacea4f34f8dd857", null ],
    [ "ssyconv", "d0/d14/group__real_s_ycomputational_gac0f11db6dfb7415b9ca1bc5b2edb643d.html#gac0f11db6dfb7415b9ca1bc5b2edb643d", null ],
    [ "ssyequb", "d0/d14/group__real_s_ycomputational_ga1ab0d003e6854b5c84dc588a978a9e1f.html#ga1ab0d003e6854b5c84dc588a978a9e1f", null ],
    [ "ssygs2", "d0/d14/group__real_s_ycomputational_ga0ea1b814a88acd6907337680dc1fde81.html#ga0ea1b814a88acd6907337680dc1fde81", null ],
    [ "ssygst", "d0/d14/group__real_s_ycomputational_gaef1e992af47469e70d21e80c16d67d1b.html#gaef1e992af47469e70d21e80c16d67d1b", null ],
    [ "ssyrfs", "d0/d14/group__real_s_ycomputational_ga71a800843ac98f1a025a5ff437e6f9a3.html#ga71a800843ac98f1a025a5ff437e6f9a3", null ],
    [ "ssyrfsx", "d0/d14/group__real_s_ycomputational_ga40ae1ffd0fcd22c6a196c09fa660a5cd.html#ga40ae1ffd0fcd22c6a196c09fa660a5cd", null ],
    [ "ssytd2", "d0/d14/group__real_s_ycomputational_gac702851ad871b3170b0566876fd588b1.html#gac702851ad871b3170b0566876fd588b1", null ],
    [ "ssytf2", "d0/d14/group__real_s_ycomputational_ga7a22a184725b704bb892c4cb3cd2f872.html#ga7a22a184725b704bb892c4cb3cd2f872", null ],
    [ "ssytf2_rook", "d0/d14/group__real_s_ycomputational_ga366e10c15d6365d941b0b915c8411ccd.html#ga366e10c15d6365d941b0b915c8411ccd", null ],
    [ "ssytrd", "d0/d14/group__real_s_ycomputational_ga6f435f24bbc42c21a66bc5774509ec86.html#ga6f435f24bbc42c21a66bc5774509ec86", null ],
    [ "ssytrd_2stage", "d0/d14/group__real_s_ycomputational_gae28ce0a4f0c6c897ac3301ba08558b26.html#gae28ce0a4f0c6c897ac3301ba08558b26", null ],
    [ "ssytrd_sy2sb", "d0/d14/group__real_s_ycomputational_gaf640b5eb84ff9eb0681a6f37b740d18c.html#gaf640b5eb84ff9eb0681a6f37b740d18c", null ],
    [ "ssytrf", "d0/d14/group__real_s_ycomputational_ga12d2e56511cf7df066712c61d9acec45.html#ga12d2e56511cf7df066712c61d9acec45", null ],
    [ "ssytrf_aa", "d0/d14/group__real_s_ycomputational_ga8a8e87ecd7aa20ae7df39944d6811878.html#ga8a8e87ecd7aa20ae7df39944d6811878", null ],
    [ "ssytrf_aa_2stage", "d0/d14/group__real_s_ycomputational_gad1b49392866a54aaaf3fb905a28f2cdc.html#gad1b49392866a54aaaf3fb905a28f2cdc", null ],
    [ "ssytrf_rook", "d0/d14/group__real_s_ycomputational_ga3ee23af3bb6160578d858a59b053f007.html#ga3ee23af3bb6160578d858a59b053f007", null ],
    [ "ssytri", "d0/d14/group__real_s_ycomputational_gaef378ec0761234aac417f487b43b7a8b.html#gaef378ec0761234aac417f487b43b7a8b", null ],
    [ "ssytri2", "d0/d14/group__real_s_ycomputational_ga7852066f959159f9701c0f63f90c5230.html#ga7852066f959159f9701c0f63f90c5230", null ],
    [ "ssytri2x", "d0/d14/group__real_s_ycomputational_ga34537bed5f8e070371776e65dd14fd16.html#ga34537bed5f8e070371776e65dd14fd16", null ],
    [ "ssytri_rook", "d0/d14/group__real_s_ycomputational_ga34452db5ae0fdbcb107128a499a16e2c.html#ga34452db5ae0fdbcb107128a499a16e2c", null ],
    [ "ssytrs", "d0/d14/group__real_s_ycomputational_gae20133a1119b69a7319783ff982c8c62.html#gae20133a1119b69a7319783ff982c8c62", null ],
    [ "ssytrs2", "d0/d14/group__real_s_ycomputational_ga0e6312aad14fb7d54e0f3ef5111ec60a.html#ga0e6312aad14fb7d54e0f3ef5111ec60a", null ],
    [ "ssytrs_aa", "d0/d14/group__real_s_ycomputational_gabdbc5db1b83d7919f2af3f921ee18625.html#gabdbc5db1b83d7919f2af3f921ee18625", null ],
    [ "ssytrs_aa_2stage", "d0/d14/group__real_s_ycomputational_ga7f826d71f9e154ac2935ee89ee655cb5.html#ga7f826d71f9e154ac2935ee89ee655cb5", null ],
    [ "ssytrs_rook", "d0/d14/group__real_s_ycomputational_ga919d6dd600fb34f939eb34e18751d702.html#ga919d6dd600fb34f939eb34e18751d702", null ],
    [ "stgsyl", "d0/d14/group__real_s_ycomputational_ga7be8a5fb25c1b67ea888747c1334d996.html#ga7be8a5fb25c1b67ea888747c1334d996", null ],
    [ "strsyl", "d0/d14/group__real_s_ycomputational_ga56e2ab6ac5906744561c4c1abb27b83d.html#ga56e2ab6ac5906744561c4c1abb27b83d", null ]
];